############################################################
# R script illustrating the use of different estimation
# algorithms in RSiena. 
# version of 3 February 2017
# written by Christian Steglich
############################################################

# Consideration to begin with:
# - has the zip-archive been unpacked?
# - do you need to set the working directory?

# load data set:
load("klas03edata.RData")
ls()

# load RSiena commands to the R namespace:
library(RSiena)

# check installed version:
packageVersion("RSiena")

# prepare data for RSiena (just the middle data period!):
thedata <- sienaDataCreate(
	friendship = sienaDependent(array(
		c(friendship.net2,friendship.net3),
		dim=c(dim(friendship.net2),2))),
	sex.M = coCovar(demographics[,1],centered=FALSE),
	primary = coDyadCovar(primary.net)
)
thedata

# specify a simple model:
themodel <- getEffects(thedata)
themodel <- includeEffects(themodel,X,interaction1='primary')
themodel <- includeEffects(themodel,sameX,interaction1='sex.M')
themodel <- includeEffects(themodel,transTrip,transRecTrip)
themodel

# define three different configurations for estimation:
options.MoM.unconditional <- sienaAlgorithmCreate(useStdInits=FALSE,
	projname='results',cond=FALSE,maxlike=FALSE,
	seed=1234567)
options.MoM.conditional <- sienaAlgorithmCreate(useStdInits=FALSE,
	projname='results',cond=TRUE,maxlike=FALSE,
	seed=1234567)
options.ML.unconditional <- sienaAlgorithmCreate(useStdInits=FALSE,
	projname='results',cond=FALSE,maxlike=TRUE,
	n3=3000,seed=1234567)
?sienaAlgorithmCreate

# There also is the variant "ML-conditional" and in the package RSienaTest,
# there are also Bayesian and GMM estimation options available, which we
# do not discuss here.

# estimate the model with each algorithm:
(results.MoM.unconditional <- siena07(options.MoM.unconditional,
	data=thedata,effects=themodel))
(results.MoM.conditional <- siena07(options.MoM.conditional,
	data=thedata,effects=themodel))
(results.ML.unconditional <- siena07(options.ML.unconditional,
	data=thedata,effects=themodel))

# Results are appended to file "results.out" in the working directory.

# If you compare results, you see that ML estimation takes much longer
# but leads to smaller standard errors (due to higher efficiency in 
# data usage).

# save results if needed later:
save.image("estimation lab results.RData")

