# the following is cut and pasted from the help function of "sienaGOF-auxiliary"
# as distributed in RSiena package version 1.1.250

   ### Here come some useful functions for building your own auxiliary statistics:
   ### First an extraction function.

   # igraphNetworkExtraction extracts simulated and observed networks
   # from the results of a siena07 run.
   # It returns the network as an edge list of class "graph"
   # according to the igraph package.
   # Ties for ordered pairs with a missing value for wave=period or period+1
   # are zeroed;
   # note that this also is done in RSiena for calculation of target statistics.
   # However, changing structurally fixed values are not taken into account.
   igraphNetworkExtraction <- function(i, data, sims, period, groupName, varName){
     require(igraph)
     dimsOfDepVar<- attr(data[[groupName]]$depvars[[varName]], "netdims")
     missings <- is.na(data[[groupName]]$depvars[[varName]][,,period]) |
                 is.na(data[[groupName]]$depvars[[varName]][,,period+1])
     if (is.null(i)) {
   # sienaGOF wants the observation:
       original <- data[[groupName]]$depvars[[varName]][,,period+1]
       original[missings] <- 0
       returnValue <- graph.adjacency(original)
     }
     else
     {
       missings <- graph.adjacency(missings)
   #sienaGOF wants the i-th simulation:
       returnValue <- graph.difference(
                graph.edgelist(sims[[i]][[groupName]][[varName]][[period]][,1:2]),
                missings)
     }
     returnValue
   }

   ### Then some auxiliary statistics.

   # GeodesicDistribution calculates the distribution of directed
   # geodesic distances; see ?sna::geodist
   # The default for \code{levls} reflects that geodesic distances larger than 5
   # do not differ appreciably with respect to interpretation.
   # Note that the levels of the result are named;
   # these names are used in the \code{plot} method.
   GeodesicDistribution <- function (i, data, sims, period, groupName,
                           varName, levls=c(1:5,Inf), cumulative=TRUE, ...) {
     x <- networkExtraction(i, data, sims, period, groupName, varName)
     require(sna)
     a <- sna::geodist(x)$gdist
     if (cumulative)
     {
       gdi <- sapply(levls, function(i){ sum(a<=i) })
     }
	 else
     {
       gdi <- sapply(levls, function(i){ sum(a==i) })
     }
     names(gdi) <- as.character(levls)
     gdi
   }

   # Holland and Leinhardt Triad Census; see ?sna::triad.census.
   TriadCensus <- function(i, data, sims, wave, groupName, varName, levls=1:16){
       unloadNamespace("igraph") # to avoid package clashes
       require(sna)
       require(network)
       x <- networkExtraction(i, data, sims, wave, groupName, varName)
       tc <- sna::triad.census(x)[1,levls]
       # names are transferred automatically
       tc
   }

  # Distribution of Burt's constraint values; see ?igraph::constraint
  # the maximum finite value is 9/8 (see Buskens and van de Rijt, AJS 2008).
  ConstraintDistribution <- function (i, data, sims, period, groupName, varName,
                           levls=c(seq(0,1.125,by=0.125)), cumulative=TRUE){
     require(igraph)
     x <- igraphNetworkExtraction(i, data, sims, period, groupName, varName)
     a <- igraph::constraint(x)
     a[is.na(a)] <- Inf
     lel <- length(levls)
     if (cumulative)
     {
       cdi <- sapply(2:lel, function(i){sum(a<=levls[i])})
     }
     else
     {
       cdi <- sapply(2:lel, function(i){
                     sum(a<=levls[i]) - sum(a <= levls[i-1])})
     }
     names(cdi) <- as.character(levls[2:lel])
     cdi
    }